@@ -21,7 +21,7 @@ from .base import (
 )
 
 if TYPE_CHECKING:
-    from typing import Final, Optional, Callable
+    from typing import Final, Optional, Callable, Any, Iterable
 
 
 class TOMLLoader:
@@ -36,11 +36,11 @@ class TOMLLoader:
                 raise err from None
 
     @staticmethod
-    def default_template():
+    def default_template() -> dict:
         return loads(files(defaults).joinpath("template.toml").read_text())
 
     @staticmethod
-    def default_config():
+    def default_config() -> dict:
         return loads(files(defaults).joinpath("config.toml").read_text())
 
 
@@ -49,7 +49,7 @@ def _merge(*dcts: dict) -> dict:
     keys in earlier dictionaries, if there is conflict.
     """
 
-    def _merge_iter(*dcts: dict):
+    def _merge_iter(*dcts: dict) -> Iterable[tuple[Any, dict]]:
         for k in set().union(*[set(dct.keys()) for dct in dcts]):
             dcts_with_key = [dct[k] for dct in dcts if k in dct.keys()]
 
@@ -71,7 +71,11 @@ class TemplateDict(dict):
         self._source = source
         self.reload()
 
-    def reload(self):
+    @classmethod
+    def from_name(cls, name: str) -> TemplateDict:
+        return cls(template_linker.file_path(name) / NAMES.template_toml)
+
+    def reload(self) -> None:
         if self._source is not None:
             dct = _merge(TOMLLoader.default_template(), TOMLLoader.load(self._source))
         else:
@@ -103,12 +107,6 @@ class TemplateDict(dict):
                 ]
 
 
-class NamedTemplateDict(TemplateDict):
-    def __init__(self, name: str) -> None:
-        self.name = name
-        super().__init__(template_linker.file_path(name) / NAMES.template_toml)
-
-
 class Config:
     """TODO: write"""
 
@@ -209,11 +207,11 @@ DATA_PATH: Final = _DataPath()
 def relative(base: str) -> Callable[[Callable[[ProjectPath], str]], property]:
     """TODO: write"""
 
-    def fset(self, value) -> None:
+    def fset(self: ProjectPath, value: str) -> None:
         del self, value
         raise AttributeError("Cannot change constant values")
 
-    def decorator(func: Callable[[ProjectPath], str]):
+    def decorator(func: Callable[[ProjectPath], str]) -> property:
         def fget(self: ProjectPath) -> Path:
             return {
                 "root": self.working_dir,
@@ -233,7 +231,7 @@ class ProjectPath:
         # do not change declaration order!
         self.working_dir = working_dir.resolve()
         self.config = Config(working_dir)
-        self.data_dir = (
+        self.data_dir: Path = (
             data_dir
             if data_dir is not None
             else self.working_dir / self.config.render["project_data_folder"]
@@ -313,7 +311,7 @@ class ProjectPath:
         """TODO: write"""
         return "pre-commit"
 
-    def mk_data_dir(self):
+    def mk_data_dir(self) -> None:
         for mode in LinkMode:
             (self.data_dir / NAMES.resource_subdir(mode)).mkdir(
                 exist_ok=True, parents=True
@@ -358,7 +356,7 @@ class FileLinker(_BaseLinker):
 class _TemplateLinker(_BaseLinker):
     """TODO: write"""
 
-    def valid_path(self, path: Path):
+    def valid_path(self, path: Path) -> bool:
         """TODO: write"""
         return (
             super().valid_path(path)
